@@ -40,6 +40,8 @@ Further updates:
 
 =item * version 0.92, published on September 18, 2006
 
+=item * version 0.93, published on September 25, 2006
+
 =back
 
 =head1 SEE ALSO
@@ -80,6 +82,7 @@ ABIGAIL
 ABLUM
 ABOUTOV
 ABREY
+ABREZINS
 ABROSNAN
 ABS
 ABURKE
@@ -139,6 +142,7 @@ AFARIZWAN
 AFERBER
 AFIELDS
 AFINDLAY
+AFN
 AFOXSON
 AFRIKA
 AFRYER
@@ -169,6 +173,7 @@ AHORNBY
 AHOSEY
 AHOYING
 AIDAN
+AIRWAVE
 AIZVORSKI
 AJACKSON
 AJAEKEL
@@ -297,6 +302,7 @@ ANIMATOR
 ANIO
 ANK
 ANKITS
+ANNADURAI
 ANNO
 ANONWB
 ANS
@@ -545,6 +551,7 @@ BETTELLI
 BETUL
 BEVANS
 BEWEGEN
+BFAGA
 BFAIST
 BGARBER
 BGIBBY
@@ -795,6 +802,7 @@ CARTER
 CASIANO
 CASSJ
 CASTLE
+CAT
 CAUSTIN
 CAVANAUGH
 CAVASQUEZ
@@ -870,6 +878,7 @@ CHESTER
 CHEWTOY
 CHGEUER
 CHGOETZE
+CHI
 CHIA
 CHICKS
 CHIPMUNK
@@ -1130,6 +1139,7 @@ DAVIDRA
 DAVIDRW
 DAVIEIRA
 DAVOD
+DAVOOD
 DAXELROD
 DAXIM
 DAZJORZ
@@ -1188,6 +1198,7 @@ DEC
 DECAY
 DECIUS
 DEEMON
+DEEPAK
 DEEPAN
 DEEPCREEK
 DEGE
@@ -1519,6 +1530,7 @@ ELAGACHE
 ELEONORA
 ELEPHANT
 ELH
+ELIAS
 ELIJAH
 ELISA
 ELIZABETH
@@ -1992,6 +2004,7 @@ HIKARINE
 HIMAZU
 HIO
 HIRO
+HIROYUKI
 HISELDL
 HITHERTO
 HJB
@@ -2087,6 +2100,7 @@ ICKHABOD
 ICRF
 ICY
 ICYDEE
+IDO
 IDORU
 IFLAN
 IFROL
@@ -2122,6 +2136,7 @@ INFOFLEX
 INGHAM
 INGOMACH
 INGY
+INITDOTD
 INSANEART
 INSANIAC
 INSTANTK
@@ -2288,6 +2303,7 @@ JDRAGO
 JDUARTER
 JDUNCAN
 JDUTTON
+JDV
 JEAANDER
 JEAGLE
 JEALLEN
@@ -2347,6 +2363,7 @@ JFLUHMANN
 JFORGET
 JFREEMAN
 JFRIEDL
+JFROEBE
 JFURNESS
 JGAMBLE
 JGARRISON
@@ -2409,6 +2426,7 @@ JJARVINEN
 JJDG
 JJGREEN
 JJHORNER
+JJMB
 JJOAO
 JJONES
 JJORDAN
@@ -2684,6 +2702,7 @@ KAHUNA
 KAIH
 KAILI
 KAKE
+KALELE
 KALIGUS
 KALLEWOOF
 KALNINS
@@ -2877,6 +2896,7 @@ KUDRA
 KULCHENKO
 KULP
 KULTAWAT
+KUMA
 KUNGFUFTR
 KURGAN
 KURIHARA
@@ -3377,6 +3397,7 @@ MJHEWITT
 MJLEEDS
 MJM
 MJP
+MJR
 MJS
 MKENNEDY
 MKHRAPOV
@@ -3440,6 +3461,7 @@ MOPOKE
 MOREGAN
 MORGOTHII
 MORNI
+MORRISNIH
 MORTENF
 MORTY
 MOSTAFAVI
@@ -3518,6 +3540,7 @@ MSS
 MSTEELE
 MSTEVENS
 MSTRAT
+MSTREEK
 MSTROUT
 MSULLIVAN
 MTHOMAS
@@ -3608,6 +3631,7 @@ NETSNAKE
 NETSRAK
 NEVDULL
 NEVES
+NEVETS
 NEXEN
 NFMNUNES
 NGEREN
@@ -3702,6 +3726,7 @@ ODIGITY
 OESI
 OESTERHOL
 OEVANS
+OFER
 OFEYAIKON
 OFUN
 OHRT
@@ -3774,6 +3799,7 @@ PARUSSEL
 PARVEZ
 PASHA
 PASKY
+PASP
 PATL
 PATM
 PATRICK
@@ -4013,6 +4039,7 @@ PTHOMSEN
 PTILL
 PTIMMINS
 PTIMOF
+PTINSLEY
 PTS
 PTULLY
 PUCKERING
@@ -4050,6 +4077,7 @@ RADER
 RADIANT
 RADKOV
 RADOS
+RADPOC
 RAFAEL
 RAGA
 RAGOFF
@@ -4135,6 +4163,7 @@ REGGERS
 REICHERT
 REID
 REITER
+REITMAN
 REITMEIE
 REITTER
 RELAIS
@@ -4222,6 +4251,7 @@ RKINYON
 RKITOVER
 RKOBES
 RKOWEN
+RKRIMEN
 RKS
 RLANDRUM
 RLATHROP
@@ -4293,6 +4323,7 @@ ROSULEK
 ROTH
 ROUGE
 ROUS
+ROWAA
 ROWLESD
 RPAGITSCH
 RPAUL
@@ -4541,6 +4572,7 @@ SHGUN
 SHIAR
 SHIBLON
 SHIELDS
+SHIGETA
 SHIGIO
 SHIJIALEE
 SHIKONO
@@ -4662,6 +4694,7 @@ SNIPER
 SNKWATT
 SNOWFLY
 SNOWHARE
+SNOYBERG
 SNS
 SOCK
 SOENKE
@@ -4829,6 +4862,8 @@ SVENH
 SVENTECH
 SVINTO
 SVITENTI
+SVV
+SWAJ
 SWALTERS
 SWAMPFOX
 SWAMPY
@@ -4923,6 +4958,7 @@ TEUN
 TEVERETT
 TEWK
 TEXMEC
+TFJELL
 TFOUCART
 TGROSE
 TGUMMELS
@@ -5158,6 +5194,7 @@ VIDUL
 VIDUR
 VIKRAMVI
 VILA
+VILEDA
 VILJUN
 VINAYSKI
 VIOSCA
@@ -5216,6 +5253,7 @@ WAYNE
 WAYNEDAV
 WAYNEM
 WAZZUTEKE
+WBAILEY
 WBAKER
 WBNIV
 WBY
@@ -5412,11 +5450,13 @@ ZIYA
 ZKESSIN
 ZLIPTON
 ZMAN
+ZMIJ
 ZOCCAV
 ZOGZAPPER
 ZOHAER
 ZOMBITHRD
 ZOOLEIKA
+ZOOT
 ZOOVY
 ZOWERS
 ZOWIE
